import 'dart:convert';
import 'dart:ui';

import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/services.dart';
import 'package:flutter_map/flutter_map.dart';
import 'package:flutter_map/plugin_api.dart';
import 'package:insuideindoor/Constant.dart';
import 'package:latlong2/latlong.dart';
import 'package:sliding_up_panel/sliding_up_panel.dart';
import 'package:http/http.dart' as http;
import 'MarkerList.dart';
import 'package:flutter_svg/flutter_svg.dart';

//export 'package:insuideindoor/main.dart' hide MyHomePageMap;

import 'response/poi_response.dart';

void main() => runApp(SlidingUpPanelExample());

class SlidingUpPanelExample extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    SystemChrome.setSystemUIOverlayStyle(SystemUiOverlayStyle(
      systemNavigationBarColor: Colors.grey[200],
      systemNavigationBarIconBrightness: Brightness.dark,
      systemNavigationBarDividerColor: Colors.black,
    ));

    return MaterialApp(
      debugShowCheckedModeBanner: false,
      title: 'SlidingUpPanel Example',
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: HomePage(),
    );
  }
}

class HomePage extends StatefulWidget {
  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  final double _initFabHeight = 360.0;
  double _fabHeight = 0;
  double _panelHeightOpen = 0;
  double _panelHeightClosed = 380.0;
  late MapController mapController;

  bool isMapRead = false;
  List<MapMarker> mapMarkerList = [];

  List<Marker> buildMarker() {
    final _markerList = <Marker>[];
    for (int i = 0; i < mapMarkerList.length; i++) {
      final mapItem = mapMarkerList[i];
      _markerList.add(
        Marker(
          height: 55,
          width: 55,
          point: mapItem.location,
          rotate: true,
          rotateOrigin: Offset.fromDirection(50),
          builder: (_) {
            return GestureDetector(
              onTap: () {
                mapController.moveAndRotate(
                    LatLng(41.25954828824802, 28.741141583911592), 16, 180);
              },
              child: Image.asset('assets/image/poi_shopping_new.png'),


            );
          },
        ),
      );
    }

    return _markerList;
  }



  @override
  void initState() {
    super.initState();
    callApi();
    _fabHeight = _initFabHeight;
    mapController = MapController();

  }

  @override
  Widget build(BuildContext context) {
    _panelHeightOpen = MediaQuery.of(context).size.height * .99;

    return Material(
      child: Stack(
        alignment: Alignment.topCenter,
        children: <Widget>[
          SlidingUpPanel(
            maxHeight: _panelHeightOpen,
            minHeight: _panelHeightClosed,
            parallaxEnabled: true,
            parallaxOffset: .5,
            body: _body(),
            panelBuilder: (sc) => _panel(sc),
            borderRadius: BorderRadius.only(
                topLeft: Radius.circular(20.0),
                topRight: Radius.circular(20.0)),
            onPanelSlide: (double pos) => setState(() {
              // _fabHeight = pos * (_panelHeightOpen - _panelHeightClosed) +
              //     _initFabHeight;
              _panelHeightClosed;
            }),
          ),

          // the fab

          Positioned(
              top: 0,
              child: ClipRRect(
                  child: BackdropFilter(
                      filter: ImageFilter.blur(sigmaX: 10, sigmaY: 10),
                      child: Container(
                        width: MediaQuery.of(context).size.width,
                        height: MediaQuery.of(context).padding.top,
                        color: Colors.transparent,
                      )))),

          //the SlidingUpPanel Title
        ],
      ),
    );
  }

  Widget _panel(ScrollController sc) {
    return MediaQuery.removePadding(
        context: context,
        removeTop: true,
        child: ListView(
          controller: sc,
          children: <Widget>[
            SizedBox(
              height: 12.0,
            ),
            Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                Container(
                  width: 47,
                  height: 5,
                  decoration: BoxDecoration(
                      color: Colors.grey[300],
                      borderRadius: BorderRadius.all(Radius.circular(12.0))),
                ),
              ],
            ),
            const SizedBox(
              height: 18.0,
            ),
            Padding(
                padding: const EdgeInsets.only(right: 10.0, left: 10.0),
                child: TextField(
                  decoration: InputDecoration(
                      border: OutlineInputBorder(
                          borderRadius: BorderRadius.circular(25.0),
                          borderSide: BorderSide.none),
                      hintStyle:
                          TextStyle(color: Color.fromRGBO(51, 51, 51, 1)),
                      hintText: "Search Mumbai Airport ",
                      filled: true,
                      fillColor: Color.fromRGBO(234, 235, 237, 1)),
                )),
            SizedBox(
              height: 10.0,
            ),
            Padding(
              padding: const EdgeInsets.fromLTRB(20.0, 12.0, 24.0, 12.0),
              child: Text("Explore",
                  textAlign: TextAlign.start,
                  style: TextStyle(
                      fontSize: 18,
                      fontStyle: FontStyle.italic,
                      color: Color.fromRGBO(102, 102, 102, 1))),
            ),
            SizedBox(
              height: 10.0,
            ),
            Padding(
              padding: EdgeInsets.only(left: 20),
              child: Row(
                children: <Widget>[
                  Expanded(
                    flex: 1,
                    child: _button(
                        "Restaurants",
                        "assets/image/restaurant_s.svg",
                        Color.fromRGBO(245, 183, 66, 1)),
                  ),
                  Expanded(
                      flex: 1,
                      child: _button("Shopping", "assets/image/shopping_s.svg",
                          Color.fromRGBO(229, 109, 214, 1))),
                ],
              ),
            ),
            SizedBox(
              height: 20.0,
            ),
            Padding(
              padding: EdgeInsets.only(left: 20),
              child: Row(
                children: <Widget>[
                  Expanded(
                      flex: 1,
                      child: _button(
                          "Facilities",
                          "assets/image/facility_s.svg",
                          Color.fromRGBO(255, 109, 110, 1))),
                  Expanded(
                      flex: 1,
                      child: _button(
                          "Utilities",
                          "assets/image/restaurant_s.svg",
                          Color.fromRGBO(164, 114, 73, 1))),
                ],
              ),
            ),
            SizedBox(
              height: 10.0,
            ),
            Expanded(
              child: Container(
                margin: const EdgeInsets.all(15.0),
                padding: const EdgeInsets.all(15.0),
                height: 90,
                decoration: BoxDecoration(
                    border: Border.all(color: Color.fromRGBO(226, 226, 226, 1)),
                    borderRadius: BorderRadius.all(Radius.circular(5))),
                child: Column(
                  children: [
                    Row(
                      children: [
                        Image.asset(
                          'assets/image/flight.png',
                          width: 25,
                          height: 25,
                        ),
                        SizedBox(
                          width: 10,
                        ),
                        Text(
                          'Boarding Starts',
                          style: TextStyle(
                              fontSize: 16,
                              color: Color.fromRGBO(34, 34, 34, 1)),
                        ),
                      ],
                    ),
                    SizedBox(
                      height: 5.0,
                    ),
                    Row(
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: [
                        Text(
                          '04.00',
                          style: TextStyle(fontSize: 16),
                        ),
                        Container(
                          width: 4.0,
                          height: 4.0,
                          margin: const EdgeInsets.only(right: 5.0, left: 5.0),
                          padding: const EdgeInsets.all(12.0),
                          decoration: BoxDecoration(
                              color: Color.fromRGBO(102, 102, 102, 1),
                              shape: BoxShape.circle,
                              boxShadow: [
                                BoxShadow(
                                  color: Color.fromRGBO(0, 0, 0, 0.15),
                                  blurRadius: 6.0,
                                )
                              ]),
                        ),
                        Text(
                          'Gate no D 47',
                          style: TextStyle(
                              fontSize: 16,
                              color: Color.fromRGBO(34, 34, 34, 1)),
                        ),
                        Container(
                          width: 4.0,
                          height: 4.0,
                          margin: const EdgeInsets.only(right: 5.0, left: 5.0),
                          padding: const EdgeInsets.all(12.0),
                          decoration: BoxDecoration(
                              color: Color.fromRGBO(102, 102, 102, 1),
                              shape: BoxShape.circle,
                              boxShadow: [
                                BoxShadow(
                                  color: Color.fromRGBO(0, 0, 0, 0.15),
                                  blurRadius: 6.0,
                                )
                              ]),
                        ),
                        Text(
                          '6E 0433',
                          style: TextStyle(
                              fontSize: 16,
                              color: Color.fromRGBO(34, 34, 34, 1)),
                        ),
                      ],
                    ),
                  ],
                ),
              ),
            )
          ],
        ));
  }

  Widget _button(String label, String svgIcon, Color color) {
    return Row(
      children: <Widget>[
        Container(
          padding: const EdgeInsets.all(12.0),
          child: SvgPicture.asset(
            svgIcon,
            height: 18,
            width: 18,
            color: Colors.white,
          ),
          decoration:
              BoxDecoration(color: color, shape: BoxShape.circle, boxShadow: [
            BoxShadow(
              color: Color.fromRGBO(0, 0, 0, 0.15),
              blurRadius: 6.0,
            )
          ]),
        ),
        SizedBox(
          width: 12.0,
        ),
        Text(
          label,
          style: TextStyle(fontSize: 16),
        ),
      ],
    );
  }

  Widget _body() {
    final showMarker = buildMarker();
    return FlutterMap(
        mapController: mapController,
        options: new MapOptions(
            center: new LatLng(41.25954828824802, 28.741141583911592),
            minZoom: 20,
            pinchMoveWinGestures: 50),
        layers: [
          TileLayerOptions(
              urlTemplate:
                  "https://api.mapbox.com/styles/v1/merrill-amm/ckz85ygks000r14qqgptjt1h5/tiles/256/{z}/{x}/{y}@2x?access_token=pk.eyJ1IjoibWVycmlsbC1hbW0iLCJhIjoiY2o4MnM0dm0wNTg5ODJ3bzNiajV1cHF2MyJ9.cLz-hmZiv5NbM4LGt-aBUA",
              additionalOptions: {
                'accesstoken':
                    'pk.eyJ1IjoiaXRzdmljayIsImEiOiJjbDBod3MyOTYwYjJ3M2tubWsxMjA5OGZrIn0.0aAnjwb-_3TkQP8WGkwf-A',
                'id': 'mapbox.mapbox-streets-v8'
              },
              maxNativeZoom: 22,
              maxZoom: 40),
          MarkerLayerOptions(
            markers: showMarker,
            rotateAlignment: Alignment.center
            // [
            //   new Marker(
            //       width: 45.0,
            //       height: 45.0,
            //       point: new LatLng(41.25981377184681, 28.742446751108982),
            //       builder: (context) => new Container(
            //             child: IconButton(
            //               icon: Icon(Icons.location_on),
            //               color: Colors.red,
            //               iconSize: 45.0,
            //               onPressed: () {
            //                 print('Marker tapped');
            //               },
            //             ),
            //           ))
            // ]
          )
        ]);
  }

  void callApi() async {
    String url = 'http://development.wisefly.in/poisroute/getnewpois';
    try {
      http.Response response = await http.post(Uri.parse(url),
          headers: {
            "Content-Type": "application/x-www-form-urlencoded",
          },
          encoding: Encoding.getByName('utf-8'),
          body: {
            'appname': "fff",
            'token': Constant.apiKey,
            'isPartner': "true"
          });
      var responseData = jsonDecode(response.body);
      var serverResponse = POI_Response.fromJson(responseData);

      print(response.statusCode);
      print(responseData);
      if (response.statusCode == 200) {
        for (int i = 0; i < serverResponse.poidataresponseList.length; i++) {
          print(i);
          PoiDataResponse poiDataResponse =
              serverResponse.poidataresponseList[i];
          List<LocationsResponse> locationsList =
              poiDataResponse.locationResponseList;
          for (LocationsResponse location in locationsList) {
            print(location.latitude);
            mapMarkerList.add(MapMarker(
                img: "",
                title: "Demo",
                location: LatLng(location.latitude, location.longitude)));
          }
        }
      }
    } on Exception catch (e) {}
  }
}
